summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-08-16 16:20:48 +0200
committerNoel Grandin <noel@peralex.com>2016-08-17 08:45:15 +0200
commit36d02d78061889ac20f9484672100e92cf1cc0c1 (patch)
tree212ef1045da71b297648780c827dcda665874d60 /include
parent48cb92cb1671bfdef3fcf43978455f19b26ca7bd (diff)
convert XPolyFlags to scoped enum
Change-Id: Ic2a6fad90a0f8c8516469db240ec9910824c1286
Diffstat (limited to 'include')
-rw-r--r--include/svx/xpoly.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/svx/xpoly.hxx b/include/svx/xpoly.hxx
index 9400ce55c015..2a5cba555b9f 100644
--- a/include/svx/xpoly.hxx
+++ b/include/svx/xpoly.hxx
@@ -37,12 +37,12 @@ class OutputDevice;
// point-styles in XPolygon:
-// NORMAL : start-/endpoint of a curve or a line
-// SMOOTH : smooth transition between curves
-// SYMMTR : smooth and symmetrical transition between curves
-// CONTROL: control handles of a Bezier curve
+// Normal : start-/endpoint of a curve or a line
+// Smooth : smooth transition between curves
+// Control: control handles of a Bezier curve
+// Symmetric : smooth and symmetrical transition between curves
-enum XPolyFlags { XPOLY_NORMAL, XPOLY_SMOOTH, XPOLY_CONTROL, XPOLY_SYMMTR };
+enum class XPolyFlags { Normal, Smooth, Control, Symmetric };
// Class XPolygon;has a point-array and a flag-array, which contains information about a particular point